@@ -22,22 +22,28 @@
              enrollNodeService);
 
   enrollNodeService.$inject = [
-    '$modal',
-    'horizon.dashboard.admin.basePath'
+    '$uibModal',
+    'horizon.dashboard.admin.ironic.basePath'
   ];
 
-  function enrollNodeService($modal, basePath) {
+  function enrollNodeService($uibModal, basePath) {
     var service = {
-      modal: modal
+      enrollNode: enrollNode
     };
 
-    function modal() {
+    /**
+     * @description Launch a modal dialog that will guide the user
+     * in enrolling a new node
+     *
+     * @return {promise} Object describing the enrolled node
+     */
+    function enrollNode() {
       var options = {
         controller: 'EnrollNodeController as ctrl',
         backdrop: 'static',
-        templateUrl: basePath + '/ironic/base-node/base-node.html'
+        templateUrl: basePath + '/base-node/base-node.html'
       };
-      return $modal.open(options);
+      return $uibModal.open(options).result;
     }
 
     return service;
